#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_SIX_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_SIX_HPP_INCLUDED

#include <boost/simd/constant/include/constants/six.hpp>

#endif
